@@ -1,7 +1,7 @@
 // -*- c++ -*-
 #ifndef _GLIBMM_ERROR_H
 #define _GLIBMM_ERROR_H
-/* $Id: error.h,v 1.1.1.1.8.1 2006/05/10 08:05:02 murrayc Exp $ */
+/* $Id: error.h,v 1.1.1.1.8.2 2006/10/04 12:03:03 murrayc Exp $ */
 
 /* Copyright 2002 The gtkmm Development Team
  *
@@ -76,7 +76,7 @@ public:
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
   static void throw_exception(GError* gobject) G_GNUC_NORETURN;
 #else
-  static std::auto_ptr<Glib::Error> throw_exception(GError* gobject) G_GNUC_NORETURN;
+  static std::auto_ptr<Glib::Error> throw_exception(GError* gobject);
 #endif //GLIBMM_EXCEPTIONS_ENABLED
 
 #endif /* DOXYGEN_SHOULD_SKIP_THIS */
