@@ -1,7 +1,7 @@
 // -*- c++ -*-
 #ifndef _GLIBMM_OBJECT_H
 #define _GLIBMM_OBJECT_H
-/* $Id: object.h,v 1.12 2006/03/08 12:23:03 murrayc Exp $ */
+/* $Id: object.h,v 1.13 2006/04/06 12:42:28 gustin Exp $ */
 
 /* Copyright 2002 The gtkmm Development Team
  *
@@ -28,6 +28,8 @@
 #include <glibmm/containerhandle_shared.h> //Because its specializations may be here.
 #include <glibmm/value.h>
 
+#include <glibmmconfig.h>
+
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
 extern "C"
 {
@@ -84,7 +86,7 @@ private:
 #endif /* DOXYGEN_SHOULD_SKIP_THIS */
 
 
-class Object : virtual public ObjectBase
+class GLIBMM_API Object : virtual public ObjectBase
 {
 public:
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
